@@ -36,7 +36,7 @@ from ossapi.enums import (GameMode, ScoreType, RankingFilter, RankingType,
     BeatmapsetDiscussionVoteSort, BeatmapsetStatus, MessageType,
     BeatmapsetSearchCategory, BeatmapsetSearchMode,
     BeatmapsetSearchExplicitContent, BeatmapsetSearchGenre,
-    BeatmapsetSearchLanguage)
+    BeatmapsetSearchLanguage, NewsPostKey, BeatmapsetSearchSort)
 from ossapi.utils import (is_compatible_type, is_primitive_type, is_optional,
     is_base_model_type, is_model_type, is_high_model_type, Field)
 from ossapi.mod import Mod
@@ -73,6 +73,8 @@ BeatmapsetSearchModeT = Union[BeatmapsetSearchMode, int]
 BeatmapsetSearchExplicitContentT = Union[BeatmapsetSearchExplicitContent, str]
 BeatmapsetSearchGenreT = Union[BeatmapsetSearchGenre, int]
 BeatmapsetSearchLanguageT = Union[BeatmapsetSearchLanguage, str]
+NewsPostKeyT = Union[NewsPostKey, str]
+BeatmapsetSearchSortT = Union[BeatmapsetSearchSort, str]
 
 BeatmapIdT = Union[int, BeatmapCompact]
 UserIdT = Union[int, UserCompact]
@@ -957,7 +959,7 @@ class OssapiV2:
     # -----
 
     @request(Scope.CHAT_WRITE)
-    def create_pm(self,
+    def send_pm(self,
         user_id: UserIdT,
         message: str,
         is_action: Optional[bool] = False
@@ -969,6 +971,8 @@ class OssapiV2:
             "is_action": is_action}
         return self._post(CreatePMResponse, "/chat/new", data=data)
 
+    # TODO deprecated, remove in v3.x.x
+    create_pm = send_pm
 
     # /comments
     # ---------
@@ -1076,11 +1080,14 @@ class OssapiV2:
     @request(scope=None)
     def news_post(self,
         news: str,
-        key: Optional[str] = None
+        key: Optional[NewsPostKeyT] = NewsPostKey.SLUG
     ) -> NewsPost:
         """
         https://osu.ppy.sh/docs/index.html#get-news-post
         """
+        # docs state key should be "unset to query by slug"
+        if key is NewsPostKey.SLUG:
+            key = None
         params = {"key": key}
         return self._get(NewsPost, f"/news/{news}", params=params)
 
@@ -1290,6 +1297,7 @@ class OssapiV2:
     @request(Scope.PUBLIC)
     def search_beatmapsets(self,
         query: Optional[str] = None,
+        *,
         mode: BeatmapsetSearchModeT = BeatmapsetSearchMode.ANY,
         category: BeatmapsetSearchCategoryT =
             BeatmapsetSearchCategory.HAS_LEADERBOARD,
@@ -1306,7 +1314,8 @@ class OssapiV2:
         force_followed_mappers: bool = False,
         force_spotlights: bool = False,
         force_featured_artists: bool = False,
-        cursor: Optional[Cursor] = None
+        cursor: Optional[Cursor] = None,
+        sort: Optional[BeatmapsetSearchSortT] = None
     ) -> BeatmapsetSearchResult:
         # Param key names are the same as https://osu.ppy.sh/beatmapsets,
         # so from eg https://osu.ppy.sh/beatmapsets?q=black&s=any we get that
@@ -1339,7 +1348,7 @@ class OssapiV2:
 
         params = {"cursor": cursor, "q": query, "s": category, "m": mode,
             "g": genre, "l": language, "nsfw": explicit_content, "e": extra,
-            "c": general}
+            "c": general, "sort": sort}
 
         # BeatmapsetSearchGenre.ANY is the default and doesn't have a correct
         # corresponding value
